@@ -13,9 +13,13 @@ class Review(models.Model):
     url = models.URLField(blank=True)
     body = RichTextField()
 
+    def __unicode__(self):
+        return '%s: %s' % (self.reviewer, self.book.title)
     class Meta:
         db_table='plicata_reviews_reviews'
 
+
+
 class Quote(models.Model):
     review = models.ForeignKey(Review)
     visible = models.BooleanField(default=True)
@@ -23,3 +27,5 @@ class Quote(models.Model):
     quote = RichTextField()
     class Meta:
         db_table='plicata_reviews_quotes'
+    def __unicode__(self):
+        return 'quote from %s' % self.review
\ No newline at end of file
